#############
Installation
#############

trackc requires Python version >= 3.8 to run.

**PyPI**

Install trackc by running:

.. code-block:: bash

    pip install trackc

update trackc by running:

.. code-block:: bash

    pip install --upgrade trackc

run this pip command to specify the version and installation source:

.. code-block:: bash

    pip install -i https://pypi.org/simple trackc==version


**Development version**

To install trackc from GitHub, run::

    pip install git+https://github.com/seqyuan/trackc@main

